package Qt::Gui::QScrollBar;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QScrollBar
# file     : QtGui/qscrollbar.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QAbstractSlider/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QScrollBar

=head1 PUBLIC METHODS

=over

=item   QScrollBar(QWidget * parent)

=item   QScrollBar(QWidget * parent = 0)

=item   QScrollBar(Qt::Orientation arg0, QWidget * parent)

=item   QScrollBar(Qt::Orientation arg0, QWidget * parent = 0)

=item   ~QScrollBar()

=item  bool event(QEvent * event)

=item  QSize sizeHint()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
